<?php

namespace Omid\OMID\Providers;

use Illuminate\Support\ServiceProvider;

class OMIDServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'o_m_i_d');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'o_m_i_d');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('omid.o_m_i_d', function ($app) {
            return $this->app->make('Omid\OMID\OMID');
        });

                // Bind Advertising to repository
        $this->app->bind(
            'Omid\OMID\Interfaces\AdvertisingRepositoryInterface',
            \Omid\OMID\Repositories\Eloquent\AdvertisingRepository::class
        );

        $this->app->register(\Omid\OMID\Providers\AuthServiceProvider::class);
                $this->app->register(\Omid\OMID\Providers\EventServiceProvider::class);
        
        $this->app->register(\Omid\OMID\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['omid.o_m_i_d'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('omid/o_m_i_d.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/o_m_i_d')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/o_m_i_d')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
